<?php

namespace Slovocast\Domain\Entity;

use DateTimeImmutable;
use Slovocast\Domain\Entity as EntityTrait;

class Episode
{
    use EntityTrait;

    private string $duration;

    public function __construct(
        private string $title,
        private string $link,
        private int $length,
        private string $description,
        private int $serialNumber,
        private bool $explicit,
        private DateTimeImmutable $publishedDate,
        private string $episodeType,
    ) {
        $this->duration = self::parseDurationFromLength($this->length);
    }

    public function getTitle(): string
    {
        return $this->title;
    }

    public function getLink(): string
    {
        return $this->link;
    }

    public function getLength(): int
    {
        return $this->length;
    }

    public function getDuration(): string
    {
        return $this->duration;
    }

    public function getDescription(): string
    {
        return $this->description;
    }

    public function getPublishedDate(): DateTimeImmutable
    {
        return $this->publishedDate;
    }

    public function getEpisodeType(): string
    {
        return $this->episodeType;
    }

    public function getSerialNumber(): int
    {
        return $this->serialNumber;
    }

    public function isExplicit(): bool
    {
        return $this->explicit;
    }

    /**
     * @TODO Figure out how to parse second to HH:MM:SS
     */
    public static function parseDurationFromLength(int $length): string
    {
        $hours = floor($length / 3600);
        $minutes = floor($length / 60) % 60;
        $seconds = $length % 60;

        $buffer = "";

        if ($hours) {
            if ($hours < 10) {
                $hours = "0" . $hours;
            }

            $buffer = "{$hours}:";
        }

        if ($minutes) {
            if ($minutes < 10) {
                $minutes = "0" . $minutes;
            }

            $buffer .= "{$minutes}:";
        } else {
            $buffer .= "00:";
        }

        if ($seconds) {
            if ($seconds < 10) {
                $seconds = "0" . $seconds;
            }
            $buffer .= "{$seconds}";
        } else {
            $buffer .= "00";
        }

        return $buffer;
    }

    /**
     * @param array $props The properties of the method
     */
    public static function fromArray(array $props): self
    {
        $episode = new self(
            $props['title'],
            $props['link'],
            (int) $props['length'],
            $props['description'],
            $props['serialNumber'],
            (bool) $props['explicit'],
            $props['publishedDate'],
            $props['episodeType']
        );

        if ($props['id']) {
            $episode->setId($props['id']);
        }

        if ($props['created_at']) {
            $episode->setCreatedAt($props['createdAt']);
        }

        if ($props['updated_id']) {
            $episode->setUpdatedAt($props['updatedAt']);
        }

        return $episode;
    }
}
