<?php

namespace Slovocast\Infrastructure\Api\Database;

use ReturnTypeWillChange;

interface DatabaseHandlerInterface 
{
    /**
     * Typically, this method would return the PDO object that represents the
     * active connection to a database.
     *
     * @return mixed The return must be an active connection to a database.
     */
    #[ReturnTypeWillChange]
    public function getConnection();

    /**
     * Get the connection string required for establishing connections to the
     * database.
     */
    public function getConnectionString(): string;

    /**
     * Retrieve a results set from the database. If there are no results, opt
     * for returning an empty array rather than throwing an Exception.
     *
     * @param string $query
     * @param array $params Either a list of params of the KV params
     * @return array The results as an array, empty if no results
     */
    public function query(string $query, array $params = []): array;

    /**
     * Used for performing inserts, updates, deletes. We should expect the
     * statement to either be successful or not - avoid throwing Exceptions
     * here as well.
     *
     * @param string $query
     * @param array $params Either a list of params, or the KV of params
     * @return bool True if successful
     */
    public function execute(string $query, array $params = []): bool;
}
