<?php

namespace Slovocast\Infrastructure\Database;

use Slovocast\Infrastructure\Api\Database\DatabaseHandlerInterface;
use PDO;

class DatabaseHandler implements DatabaseHandlerInterface
{
    private PDO $handle;

    /**
     * @param string $host
     * @param string $username
     * @param string $password
     * @param string $database
     * @param int $port
     */
    public function __construct(
        private string $host,
        private string $username,
        private string $password,
        private string $database,
        private int $port = 3306
    ) {
        $this->handle = new PDO(
            $this->getConnectionString(),
            $this->username,
            $this->password
        );
    }

    /**
     * @return PDO For this particular Handler we will return the PDO object
     */
    public function getConnection(): PDO
    {
        return $this->handle;
    }

    public function getConnectionString(): string
    {
        return "mysql:dbname={$this->database};"
            . "host={$this->host};"
            . "port={$this->port}";
    }

    public function getHost(): string
    {
        return $this->host;
    }

    public function getDatabase(): string
    {
        return $this->database;
    }

    public function query(string $query, array $params = []): array
    {
        $statement = $this->handle->prepare($query);
        $statement->execute($params);
        return $statement->fetchAll(PDO::FETCH_ASSOC);
    }

    public function execute(string $query, array $params = []): bool
    {
        $statement = $this->handle->prepare($query);
        return $statement->execute($params);
    }
}
